==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/tr/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Özel alanlar',
    'field'		                => 'Alan',
    'about_fieldsets_title'		=> 'Alan kümeleri hakkında',
    'about_fieldsets_text'		=> 'Alan kümeleri, belirli varlık model türleri için sıklıkla yeniden kullanılan özel alan grupları oluşturmanızı sağlar.',
    'custom_format'             => 'Özel biçim...',
    'encrypt_field'      	        => 'Veritabanındaki bu alanın değerini şifreleme',
    'encrypt_field_help'      => 'UYARI: Bir alanı şifrelemek, onu aranamaz hale getirir.',
    'encrypted'      	        => 'Şifreli',
    'fieldset'      	        => 'Alan kümesi',
    'qty_fields'      	      => 'Miktar alanları',
    'fieldsets'      	        => 'Alan kümeleri',
    'fieldset_name'           => 'Alan kümesi adı',
    'field_name'              => 'Alan Adı',
    'field_values'            => 'Alan değerleri',
    'field_values_help'       => 'Seçilebilir seçenekler, her satıra bir tane ekleyin. İlk satır dışındaki boş satırlar yoksayılacaktır.',
    'field_element'           => 'Form öğesi',
    'field_element_short'     => 'Öğe',
    'field_format'            => 'Düzen',
    'field_custom_format'     => 'Özel biçim',
    'field_custom_format_help'     => 'Bu alan doğrulama için bir regex ifadesi kullanmanıza izin verir. Bu alan "regex:" ile başlamalı - örneğin, özel alan değerinin geçerli bir IMEI (15 basamaklı) olmasını sağlamak için <code>regex:/^[0-9]{15}$/</code> şeklinde kodlamalısınız.',
    'required'   		          => 'Gerekli',
    'req'   		              => 'Talep.',
    'used_by_models'   		    => 'Modellerle Kullanılmıştır',
    'order'   		            => 'Sipariş',
    'create_fieldset'         => 'Yeni alan kümesi',
    'create_field'            => 'Yeni özel alan',
    'value_encrypted'      	        => 'Bu alanın değeri veritabanında şifrelidir. Yalnızca yönetici kullanıcıları şifresi çözülen değeri görüntüleyebilir',
    'show_in_email'     => 'Bu alandaki değer kullanıcıya gönderilen ödeme e-postalara dahil edilsin mi? Şifreli alanlar e-postalarda yer alamaz.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/tr/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Özel alanlar',
    'manage'                    => 'Yönet',
    'field'		                => 'Alan',
    'about_fieldsets_title'		=> 'Alan kümeleri hakkında',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Veritabanındaki bu alanın değerini şifreleme',
    'encrypt_field_help'      => 'UYARI: Bir alanı şifrelemek, onu aranamaz hale getirir.',
    'encrypted'      	        => 'Şifreli',
    'fieldset'      	        => 'Alan kümesi',
    'qty_fields'      	      => 'Miktar alanları',
    'fieldsets'      	        => 'Alan kümeleri',
    'fieldset_name'           => 'Alan kümesi adı',
    'field_name'              => 'Alan Adı',
    'field_values'            => 'Alan değerleri',
    'field_values_help'       => 'Seçilebilir seçenekler, her satıra bir tane ekleyin. İlk satır dışındaki boş satırlar yoksayılacaktır.',
    'field_element'           => 'Form öğesi',
    'field_element_short'     => 'Öğe',
    'field_format'            => 'Düzen',
    'field_custom_format'     => 'Özel biçim',
    'field_custom_format_help'     => 'Bu alan doğrulama için bir regex ifadesi kullanmanıza izin verir. Bu alan "regex:" ile başlamalı - örneğin, özel alan değerinin geçerli bir IMEI (15 basamaklı) olmasını sağlamak için <code>regex:/^[0-9]{15}$/</code> şeklinde kodlamalısınız.',
    'required'   		          => 'Gerekli',
    'req'   		              => 'Talep.',
    'used_by_models'   		    => 'Modellerle Kullanılmıştır',
    'order'   		            => 'Sipariş',
    'create_fieldset'         => 'Yeni alan kümesi',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Yeni özel alan',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Bu alanın değeri veritabanında şifrelidir. Yalnızca yönetici kullanıcıları şifresi çözülen değeri görüntüleyebilir',
    'show_in_email'     => 'Bu alandaki değer kullanıcıya gönderilen ödeme e-postalara dahil edilsin mi? Şifreli alanlar e-postalarda yer alamaz.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Yeniden Sırala',
    'db_field' => 'Veri Tabanı Sütunları',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'Bu değer tüm varlıklarda benzersiz olmalıdır',
    'unique' => 'Benzersiz',
];
